@@ -39,10 +39,12 @@
 #include <glib/gi18n.h>
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
-#include <mate-keyring.h>
-#include <mateconf/mateconf-client.h>
 #include <libupower-glib/upower.h>
 
+#ifdef WITH_KEYRING
+#include <mate-keyring.h>
+#endif /* WITH_KEYRING */
+
 #include "egg-debug.h"
 #include "egg-console-kit.h"
 
@@ -55,7 +57,7 @@
 
 struct GpmControlPrivate
 {
-	MateConfClient		*conf;
+	GSettings		*settings;
 	UpClient		*client;
 };
 
@@ -103,7 +105,7 @@ gpm_control_shutdown (GpmControl *control, GError **error)
 /**
  * gpm_control_get_lock_policy:
  * @control: This class instance
- * @policy: The policy mateconf string.
+ * @policy: The policy string.
  *
  * This function finds out if we should lock the screen when we do an
  * action. It is required as we can either use the mate-screensaver policy
@@ -116,15 +118,33 @@ gpm_control_get_lock_policy (GpmControl *control, const gchar *policy)
 {
 	gboolean do_lock;
 	gboolean use_ss_setting;
-	/* This allows us to over-ride the custom lock settings set in mateconf
+	const char * const *schemas;
+	gboolean schema_exists;
+	gint i;
+
+	/* Check if the mate-screensaver schema exists before trying to read
+	   the lock setting to prevent crashing. See GNOME bug #651225. */
+	schemas = g_settings_list_schemas ();
+	schema_exists = FALSE;
+	for (i = 0; schemas[i] != NULL; i++) {
+		if (g_strcmp0 (schemas[i], GS_SETTINGS_SCHEMA) == 0) {
+			schema_exists = TRUE;
+			break;
+		}
+	}
+
+	/* This allows us to over-ride the custom lock settings set
 	   with a system default set in mate-screensaver.
 	   See bug #331164 for all the juicy details. :-) */
-	use_ss_setting = mateconf_client_get_bool (control->priv->conf, GPM_CONF_LOCK_USE_SCREENSAVER, NULL);
-	if (use_ss_setting) {
-		do_lock = mateconf_client_get_bool (control->priv->conf, GS_PREF_LOCK_ENABLED, NULL);
+	use_ss_setting = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_LOCK_USE_SCREENSAVER);
+	if (use_ss_setting && schema_exists) {
+		GSettings *settings_ss;
+		settings_ss = g_settings_new (GS_SETTINGS_SCHEMA);
+		do_lock = g_settings_get_boolean (settings_ss, GS_SETTINGS_PREF_LOCK_ENABLED);
 		egg_debug ("Using ScreenSaver settings (%i)", do_lock);
+		g_object_unref (settings_ss);
 	} else {
-		do_lock = mateconf_client_get_bool (control->priv->conf, policy, NULL);
+		do_lock = g_settings_get_boolean (control->priv->settings, policy);
 		egg_debug ("Using custom locking settings (%i)", do_lock);
 	}
 	return do_lock;
@@ -140,13 +160,20 @@ gpm_control_suspend (GpmControl *control, GError **error)
 	gboolean ret = FALSE;
 	gboolean do_lock;
 	gboolean nm_sleep;
-	gboolean lock_mate_keyring;
-	MateKeyringResult keyres;
 	GpmScreensaver *screensaver;
 	guint32 throttle_cookie = 0;
+#ifdef WITH_KEYRING
+	gboolean lock_mate_keyring;
+	MateKeyringResult keyres;
+#endif /* WITH_KEYRING */
+#ifdef WITH_SYSTEMD_SLEEP
+	GError *dbus_error = NULL;
+	DBusGProxy *proxy;
+	GVariant *res;
+#endif
 
 	screensaver = gpm_screensaver_new ();
-
+#ifndef WITH_SYSTEMD_SLEEP
 	g_object_get (control->priv->client,
 		      "can-suspend", &allowed,
 		      NULL);
@@ -155,22 +182,25 @@ gpm_control_suspend (GpmControl *control, GError **error)
 		g_set_error_literal (error, GPM_CONTROL_ERROR, GPM_CONTROL_ERROR_GENERAL, "Cannot suspend");
 		goto out;
 	}
+#endif
 
+#ifdef WITH_KEYRING
 	/* we should perhaps lock keyrings when sleeping #375681 */
-	lock_mate_keyring = mateconf_client_get_bool (control->priv->conf, GPM_CONF_LOCK_MATE_KEYRING_SUSPEND, NULL);
+	lock_mate_keyring = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_LOCK_KEYRING_SUSPEND);
 	if (lock_mate_keyring) {
 		keyres = mate_keyring_lock_all_sync ();
 		if (keyres != MATE_KEYRING_RESULT_OK)
 			egg_warning ("could not lock keyring");
 	}
+#endif /* WITH_KEYRING */
 
-	do_lock = gpm_control_get_lock_policy (control, GPM_CONF_LOCK_ON_SUSPEND);
+	do_lock = gpm_control_get_lock_policy (control, GPM_SETTINGS_LOCK_ON_SUSPEND);
 	if (do_lock) {
 		throttle_cookie = gpm_screensaver_add_throttle (screensaver, "suspend");
 		gpm_screensaver_lock (screensaver);
 	}
 
-	nm_sleep = mateconf_client_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, NULL);
+	nm_sleep = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_NETWORKMANAGER_SLEEP);
 	if (nm_sleep)
 		gpm_networkmanager_sleep ();
 
@@ -178,7 +208,41 @@ gpm_control_suspend (GpmControl *control, GError **error)
 	egg_debug ("emitting sleep");
 	g_signal_emit (control, signals [SLEEP], 0, GPM_CONTROL_ACTION_SUSPEND);
 
+#ifdef WITH_SYSTEMD_SLEEP
+	/* sleep via logind */
+	proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
+			G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
+			NULL,
+			"org.freedesktop.login1",
+			"/org/freedesktop/login1",
+			"org.freedesktop.login1.Manager",
+			NULL,
+			&dbus_error );
+    if (proxy == NULL) {
+        egg_error("Error connecting to dbus - %s", dbus_error->message);
+        fprintf(stderr,"Error connecting to dbus - %s", dbus_error->message);
+        g_error_free (dbus_error);
+        return -1;
+    }
+    g_dbus_proxy_call_sync (proxy, "Suspend", 
+                            g_variant_new( "(b)",FALSE),
+                            G_DBUS_CALL_FLAGS_NONE,
+                            -1,
+                            NULL,
+                            &dbus_error
+                            );
+    if (dbus_error != NULL ) {
+	    egg_debug ("Error in dbus - %s", dbus_error->message);
+	    g_error_free (dbus_error);
+	    ret = TRUE;
+    }
+    else {
+	    ret = TRUE;
+    }
+    g_object_unref(proxy);
+#else
 	ret = up_client_suspend_sync (control->priv->client, NULL, error);
+#endif
 
 	egg_debug ("emitting resume");
 	g_signal_emit (control, signals [RESUME], 0, GPM_CONTROL_ACTION_SUSPEND);
@@ -189,7 +253,7 @@ gpm_control_suspend (GpmControl *control, GError **error)
 			gpm_screensaver_remove_throttle (screensaver, throttle_cookie);
 	}
 
-	nm_sleep = mateconf_client_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, NULL);
+	nm_sleep = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_NETWORKMANAGER_SLEEP);
 	if (nm_sleep)
 		gpm_networkmanager_wake ();
 
@@ -208,13 +272,21 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 	gboolean ret = FALSE;
 	gboolean do_lock;
 	gboolean nm_sleep;
-	gboolean lock_mate_keyring;
-	MateKeyringResult keyres;
 	GpmScreensaver *screensaver;
 	guint32 throttle_cookie = 0;
+#ifdef WITH_KEYRING
+	gboolean lock_mate_keyring;
+	MateKeyringResult keyres;
+#endif /* WITH_KEYRING */
+
+#ifdef WITH_SYSTEMD_SLEEP
+	GError *dbus_error = NULL;
+	DBusGProxy *proxy;
+#endif
 
 	screensaver = gpm_screensaver_new ();
 
+#ifndef WITH_SYSTEMD_SLEEP
 	g_object_get (control->priv->client,
 		      "can-hibernate", &allowed,
 		      NULL);
@@ -223,31 +295,67 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 		g_set_error_literal (error, GPM_CONTROL_ERROR, GPM_CONTROL_ERROR_GENERAL, "Cannot hibernate");
 		goto out;
 	}
+#endif
 
+#ifdef WITH_KEYRING
 	/* we should perhaps lock keyrings when sleeping #375681 */
-	lock_mate_keyring = mateconf_client_get_bool (control->priv->conf, GPM_CONF_LOCK_MATE_KEYRING_HIBERNATE, NULL);
+	lock_mate_keyring = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_LOCK_KEYRING_HIBERNATE);
 	if (lock_mate_keyring) {
 		keyres = mate_keyring_lock_all_sync ();
 		if (keyres != MATE_KEYRING_RESULT_OK) {
 			egg_warning ("could not lock keyring");
 		}
 	}
+#endif /* WITH_KEYRING */
 
-	do_lock = gpm_control_get_lock_policy (control, GPM_CONF_LOCK_ON_HIBERNATE);
+	do_lock = gpm_control_get_lock_policy (control, GPM_SETTINGS_LOCK_ON_HIBERNATE);
 	if (do_lock) {
 		throttle_cookie = gpm_screensaver_add_throttle (screensaver, "hibernate");
 		gpm_screensaver_lock (screensaver);
 	}
 
-	nm_sleep = mateconf_client_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, NULL);
+	nm_sleep = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_NETWORKMANAGER_SLEEP);
 	if (nm_sleep)
 		gpm_networkmanager_sleep ();
 
 	egg_debug ("emitting sleep");
 	g_signal_emit (control, signals [SLEEP], 0, GPM_CONTROL_ACTION_HIBERNATE);
 
+#ifdef WITH_SYSTEMD_SLEEP
+	/* sleep via logind */
+	fprintf(stderr,"logind suspend\n");
+	proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
+			G_DBUS_PROXY_FLAGS_DO_NOT_LOAD_PROPERTIES,
+			NULL,
+			"org.freedesktop.login1",
+			"/org/freedesktop/login1",
+			"org.freedesktop.login1.Manager",
+			NULL,
+			&dbus_error );
+    if (proxy == NULL) {
+        egg_error("Error connecting to dbus - %s", dbus_error->message);
+        fprintf(stderr,"Error connecting to dbus - %s", dbus_error->message);
+        g_error_free (dbus_error);
+        return -1;
+    }
+    g_dbus_proxy_call_sync (proxy, "Hibernate", 
+                            g_variant_new( "(b)",FALSE),
+                            G_DBUS_CALL_FLAGS_NONE,
+                            -1,
+                            NULL,
+                            &dbus_error
+                            );
+    if (dbus_error != NULL ) {
+	    egg_debug ("Error in dbus - %s", dbus_error->message);
+	    g_error_free (dbus_error);
+	    ret = TRUE;
+    }
+    else {
+	    ret = TRUE;
+    }
+#else
 	ret = up_client_hibernate_sync (control->priv->client, NULL, error);
-
+#endif
 	egg_debug ("emitting resume");
 	g_signal_emit (control, signals [RESUME], 0, GPM_CONTROL_ACTION_HIBERNATE);
 
@@ -257,7 +365,7 @@ gpm_control_hibernate (GpmControl *control, GError **error)
 			gpm_screensaver_remove_throttle (screensaver, throttle_cookie);
 	}
 
-	nm_sleep = mateconf_client_get_bool (control->priv->conf, GPM_CONF_NETWORKMANAGER_SLEEP, NULL);
+	nm_sleep = g_settings_get_boolean (control->priv->settings, GPM_SETTINGS_NETWORKMANAGER_SLEEP);
 	if (nm_sleep)
 		gpm_networkmanager_wake ();
 
@@ -278,7 +386,7 @@ gpm_control_finalize (GObject *object)
 	g_return_if_fail (GPM_IS_CONTROL (object));
 	control = GPM_CONTROL (object);
 
-	g_object_unref (control->priv->conf);
+	g_object_unref (control->priv->settings);
 	g_object_unref (control->priv->client);
 
 	g_return_if_fail (control->priv != NULL);
@@ -326,7 +434,7 @@ gpm_control_init (GpmControl *control)
 	control->priv = GPM_CONTROL_GET_PRIVATE (control);
 
 	control->priv->client = up_client_new ();
-	control->priv->conf = mateconf_client_get_default ();
+	control->priv->settings = g_settings_new (GPM_SETTINGS_SCHEMA);
 }
 
 /**
